import unittest
from the_weather import *

class WeatherTest(unittest.TestCase):
    
    def test_init(self):
        weather = Weather(22025)
        self.assertEqual(weather.res.status_code, 200)

    def test_invalid_measure(self):
        with self.assertRaises(TypeError):
            Weather(22801, "invalid")
    

if __name__ == '__main__':
    unittest.main()


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="google_trendy",
    version="1.2",
    author="Michael Mondoro",
    author_email="michaelmondoro@gmail.com",
    description="Package for getting and analyzing tending Google searches",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/michaelMondoro/the_weather",
    packages=setuptools.find_packages(exclude="tests"),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[],
    python_requires='>=3.7',
)
